@@ -2,8 +2,8 @@
  * libdmtx - Data Matrix Encoding/Decoding Library
  * Copyright 2008, 2009 Mike Laughton. All rights reserved.
  *
- * See LICENSE file in parent directory for full terms of
- * use and distribution.
+ * See LICENSE file in the main project directory for full
+ * terms of use and distribution.
  *
  * Contact: Mike Laughton <mike@dragonflylogic.com>
  *
@@ -32,7 +32,7 @@ extern "C" {
 #define M_PI_2    1.57079632679489661923
 #endif
 
-#define DmtxVersion              "0.7.3"
+#define DmtxVersion              "0.7.5"
 
 #define DmtxUndefined                 -1
 
@@ -271,7 +271,7 @@ struct DmtxEncodeStream_struct
    int inputNext;             /* Index of next unprocessed input word in queue */
    int outputChainValueCount; /* Count of output values pushed within current scheme chain */
    int outputChainWordCount;  /* Count of output words pushed within current scheme chain */
-   int reason;                /* Reason for status */
+   char *reason;              /* Reason for status */
    int sizeIdx;               /* Symbol size of completed stream */
    DmtxStatus status;
    DmtxByteList *input;
@@ -609,6 +609,7 @@ extern int dmtxGetBlockDataSize(int sizeIdx, int blockIdx);
 /* dmtxbytelist.c */
 extern DmtxByteList dmtxByteListBuild(DmtxByte *storage, int capacity);
 extern void dmtxByteListInit(DmtxByteList *list, int length, DmtxByte value, DmtxPassFail *passFail);
+extern void dmtxByteListClear(DmtxByteList *list);
 extern DmtxBoolean dmtxByteListHasCapacity(DmtxByteList *list);
 extern void dmtxByteListCopy(DmtxByteList *dst, const DmtxByteList *src, DmtxPassFail *passFail);
 extern void dmtxByteListPush(DmtxByteList *list, DmtxByte value, DmtxPassFail *passFail);
